def add(num1,num2):
    total = str(num1 + num2)
    return total
def sub(num1,num2):
    total = str(num1 - num2)
    return total
def mul(num1,num2):
    total = str(num1 * num2)
    return total
def div(num1,num2):
    total = str(num1 / num2)
    return total
def add_print(num1,num2):
    total = str(num1 + num2)
    print(total)
def sub_print(num1,num2):
    total = str(num1 - num2)
    print(total)
def mul_print(num1,num2):
    total = str(num1 * num2)
    print(total)
def div_print(num1,num2):
    total = str(num1 / num2)
    print(total)